==> haskell-missingh-1.4.0.1-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-missingh.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: MissingH
version: 1.4.0.1
id: MissingH-1.4.0.1-CeicSZl0Yex1Yuk7KbB55h
key: MissingH-1.4.0.1-CeicSZl0Yex1Yuk7KbB55h
license: BSD3
copyright: Copyright (c) 2004-2016 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
stability: Beta
homepage: http://software.complete.org/missingh
synopsis: Large utility library
description:
    MissingH is a library of all sorts of utility functions for
    Haskell programmers.  It is written in pure Haskell and thus should
    be extremely portable and easy to use.
category: Unclassified
author: John Goerzen
exposed: True
indefinite: False
exposed-modules:
    Control.Concurrent.Thread.Utils Data.BinPacking Data.Bits.Utils
    Data.CSV Data.Compression.Inflate Data.Either.Utils
    Data.Hash.CRC32.GZip Data.Hash.MD5 Data.Hash.MD5.Zord64_HARD
    Data.List.Utils Data.MIME.Types Data.Map.Utils Data.Maybe.Utils
    Data.Progress.Meter Data.Progress.Tracker Data.Quantity
    Data.String.Utils Data.Tuple.Utils Network.Email.Mailbox
    Network.Email.Sendmail Network.SocketServer Network.Utils
    System.Cmd.Utils System.Console.GetOpt.Utils System.Daemon
    System.Debian System.Debian.ControlParser System.FileArchive.GZip
    System.IO.Binary System.IO.HVFS System.IO.HVFS.Combinators
    System.IO.HVFS.InstanceHelpers System.IO.HVFS.Utils System.IO.HVIO
    System.IO.PlafCompat System.IO.StatCompat System.IO.Utils
    System.IO.WindowsCompat System.Path System.Path.Glob
    System.Path.NameManip System.Path.WildMatch System.Posix.Consts
    System.Time.Utils Text.ParserCombinators.Parsec.Utils
abi: 74c4108f2a54ba102093868fb6b3ea6b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/MissingH-1.4.0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/MissingH-1.4.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/MissingH-1.4.0.1
hs-libraries: HSMissingH-1.4.0.1-CeicSZl0Yex1Yuk7KbB55h
depends:
    network-2.6.3.2-Elf6Dxkfz0iKjb1zv5eBTP
    parsec-3.1.11-1k1VJixRpBgKJgdIEz2OP7 base-4.10.1.0
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4
    regex-compat-0.95.1-vWU5STOtMi6yQryYjRhah filepath-1.4.1.2
    hslogger-1.2.10-130Szb1sQo3JyMDvQNrKMO directory-1.3.0.2
    random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We process-1.6.1.0
    old-time-1.1.0.3-46BMzRKZrT477y0C8mrrus containers-0.5.10.2
    old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9 array-0.5.2.0 time-1.8.0.2
    unix-2.7.2.2
abi-depends: network-2.6.3.2-Elf6Dxkfz0iKjb1zv5eBTP=be5c9ce6f97dd4968397992ca4f22add
             parsec-3.1.11-1k1VJixRpBgKJgdIEz2OP7=de60442ea6c5324e39bc534a733c07dd
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=1e76d6f7019a4b5c8c222b2fbbb06681
             HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4=55cadea04bfe420efb47c0d18f2d6d9c
             regex-compat-0.95.1-vWU5STOtMi6yQryYjRhah=a1ec8abf4469a7e5270d04e1a7ce76e2
             filepath-1.4.1.2=f49190c9093d895f9f159c40e7d1ff46
             hslogger-1.2.10-130Szb1sQo3JyMDvQNrKMO=de2070debe700d3dc04645be8bc5642c
             directory-1.3.0.2=60cb0805ce3e0135e907efd1476a027a
             random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We=bddaa4d6513f513fbc23673a7214617b
             process-1.6.1.0=df30c64bceb5deb119c7833d040aa380
             old-time-1.1.0.3-46BMzRKZrT477y0C8mrrus=6e88558dac665c66c2d7d633e15999e5
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9=cd49072ee3f44d2ed6a40aa4d5cec718
             array-0.5.2.0=26dc06837667b4f45ea7fe07c114ff89
             time-1.8.0.2=7cc0324e0aef789d5f0780f6640c241b
             unix-2.7.2.2=1e3caa57de79efd01f1c7566785dcafa
haddock-interfaces: /usr/share/doc/haskell-missingh/html/MissingH.haddock
haddock-html: /usr/share/doc/haskell-missingh/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-missingh-1.4.0.1-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-missingh.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: MissingH
version: 1.4.0.1
id: MissingH-1.4.0.1-6P1mJkrTQI8LIAfZAYaeQa
key: MissingH-1.4.0.1-6P1mJkrTQI8LIAfZAYaeQa
license: BSD3
copyright: Copyright (c) 2004-2016 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
stability: Beta
homepage: http://software.complete.org/missingh
synopsis: Large utility library
description:
    MissingH is a library of all sorts of utility functions for
    Haskell programmers.  It is written in pure Haskell and thus should
    be extremely portable and easy to use.
category: Unclassified
author: John Goerzen
exposed: True
indefinite: False
exposed-modules:
    Control.Concurrent.Thread.Utils Data.BinPacking Data.Bits.Utils
    Data.CSV Data.Compression.Inflate Data.Either.Utils
    Data.Hash.CRC32.GZip Data.Hash.MD5 Data.Hash.MD5.Zord64_HARD
    Data.List.Utils Data.MIME.Types Data.Map.Utils Data.Maybe.Utils
    Data.Progress.Meter Data.Progress.Tracker Data.Quantity
    Data.String.Utils Data.Tuple.Utils Network.Email.Mailbox
    Network.Email.Sendmail Network.SocketServer Network.Utils
    System.Cmd.Utils System.Console.GetOpt.Utils System.Daemon
    System.Debian System.Debian.ControlParser System.FileArchive.GZip
    System.IO.Binary System.IO.HVFS System.IO.HVFS.Combinators
    System.IO.HVFS.InstanceHelpers System.IO.HVFS.Utils System.IO.HVIO
    System.IO.PlafCompat System.IO.StatCompat System.IO.Utils
    System.IO.WindowsCompat System.Path System.Path.Glob
    System.Path.NameManip System.Path.WildMatch System.Posix.Consts
    System.Time.Utils Text.ParserCombinators.Parsec.Utils
abi: aa0c077bc87bb8ad352ad189cdc2ce82
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/MissingH-1.4.0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/MissingH-1.4.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/MissingH-1.4.0.1
hs-libraries: HSMissingH-1.4.0.1-6P1mJkrTQI8LIAfZAYaeQa
depends:
    network-2.6.3.4-8L4uSVu9H2RKc9gFtidscN
    parsec-3.1.13.0-lnA0oAxTgL1KjACiBdQ3F base-4.10.1.0
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4
    regex-compat-0.95.1-9KJ50feXnCBDgyZKne44oW filepath-1.4.1.2
    hslogger-1.2.10-Igulwe0u9C38EYtisFgI2O directory-1.3.0.2
    random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We process-1.6.1.0
    old-time-1.1.0.3-46BMzRKZrT477y0C8mrrus containers-0.5.10.2
    old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9 array-0.5.2.0 time-1.8.0.2
    unix-2.7.2.2
abi-depends: network-2.6.3.4-8L4uSVu9H2RKc9gFtidscN=ea581c47f7afb58d7ebae83854dc6afa
             parsec-3.1.13.0-lnA0oAxTgL1KjACiBdQ3F=688f5e7444a80128e4a1c39bd128d195
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=ada793ec1f149425d0c0689d53e1173b
             HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4=55cadea04bfe420efb47c0d18f2d6d9c
             regex-compat-0.95.1-9KJ50feXnCBDgyZKne44oW=8fa7c6adbb4703b4ea7d5567ae930912
             filepath-1.4.1.2=f49190c9093d895f9f159c40e7d1ff46
             hslogger-1.2.10-Igulwe0u9C38EYtisFgI2O=098b32ca09ca4aada00f845f9d1ba28a
             directory-1.3.0.2=60cb0805ce3e0135e907efd1476a027a
             random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We=bddaa4d6513f513fbc23673a7214617b
             process-1.6.1.0=df30c64bceb5deb119c7833d040aa380
             old-time-1.1.0.3-46BMzRKZrT477y0C8mrrus=6e88558dac665c66c2d7d633e15999e5
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             old-locale-1.0.0.7-uLYLcRn7Nv8SkmeS8fMf9=cd49072ee3f44d2ed6a40aa4d5cec718
             array-0.5.2.0=26dc06837667b4f45ea7fe07c114ff89
             time-1.8.0.2=7cc0324e0aef789d5f0780f6640c241b
             unix-2.7.2.2=1e3caa57de79efd01f1c7566785dcafa
haddock-interfaces: /usr/share/doc/haskell-missingh/html/MissingH.haddock
haddock-html: /usr/share/doc/haskell-missingh/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
